# © 2019 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models

PROJECT_STATUS = [
    ("1_information", "Phase d'information"),
    ("2_pre-diagnostic", "Phase de pré-diagnostic"),
    ("3_accompagnement", "Phase d'accompagnement projet"),
    ("4_suivi", "Phase de suivi"),
    ("5_abandonne", "Projet abandonné"),
]


class ScopStatusWizard(models.TransientModel):
    _name = "scop.status.wizard"
    _description = "Wizard changement de statut projet"

    # Default functions
    @api.model
    def _default_partner_id(self):
        return self.env.context.get("active_id")

    @api.model
    def _default_project_status(self):
        return (
            self.env["res.partner"]
            .browse(self.env.context.get("active_id"))
            .project_status
        )

    # Fields common
    partner_id = fields.Many2one(
        comodel_name="res.partner",
        string="Partner",
        default=_default_partner_id,
    )

    # Informations Bandeau
    project_status = fields.Selection(
        selection=PROJECT_STATUS,
        string="Statut projet actuel",
        default=_default_project_status,
    )
    project_status_new = fields.Selection(
        selection=PROJECT_STATUS,
        string="Statut projet nouveau",
    )

    def change_project_status(self):
        self.partner_id.write({"project_status": self.project_status_new})
